@@ -33,13 +33,13 @@ class BotMenu(BaseMenu):
                 for bot in BotValidator.all_valid_in_dir(actual_dir):
                     try:
                         # Show everything except dir and .bot
-                        with open(os.path.join(actual_dir, bot), "r") as f:
+                        with open(os.path.join(actual_dir, bot, "config.bot"), "r") as f:
                             config = yaml.safe_load(f)
                         # If we are hidden, or in edit mode with hidden_edit, then don't show.
                         if not config.get("hidden", False) and not (
                             config.get("hidden_edit", False) and len(self.bot_keys) == 0
                         ):
-                            self.available_bots.append((bot[:-4], os.path.join(actual_dir, bot), rel_dir, bot))
+                            self.available_bots.append((bot, os.path.join(actual_dir, bot), rel_dir, bot))
                     except Exception as e:
                         sentry_sdk.capture_exception(e)
                         error_bots.append(os.path.join(actual_dir, bot))
@@ -123,9 +123,11 @@ class BotMenu(BaseMenu):
                 image = pygame.Surface(preview_size)
                 image.fill(pygame.Color(self.bg.background_colour))
             else:
-                with open(self.available_bots[self.bot_index][1], "r") as f:
+                with open(os.path.join(self.available_bots[self.bot_index][1], "config.bot"), "r") as f:
                     config = yaml.safe_load(f)
-                bot_preview = find_abs(config["preview_path"], allowed_areas=asset_locations())
+                bot_preview = os.path.join(
+                    self.available_bots[self.bot_index][1], config.get("preview_path", "preview.png")
+                )
                 image = pygame.image.load(bot_preview)
         except Exception as e:
             sentry_sdk.capture_exception(e)
@@ -146,39 +148,39 @@ class BotMenu(BaseMenu):
         self._all_objs.append(self.preview_image)
 
         if len(self.bot_keys) == 0:
-            settings_size = preview_size[0] * 0.4, preview_size[1] * 0.4
-            settings_button_pos = (
-                self._size[0] * 0.9 - settings_size[0] - 10,
+            folder_size = preview_size[0] * 0.4, preview_size[1] * 0.4
+            folder_button_pos = (
+                self._size[0] * 0.9 - folder_size[0] - 10,
                 self._size[1] * 0.1 + preview_size[1] + 10,
             )
-            settings_icon_size = settings_size[1] * 0.6, settings_size[1] * 0.6
-            self.settings_button = pygame_gui.elements.UIButton(
-                relative_rect=pygame.Rect(*settings_button_pos, *settings_size),
+            folder_icon_size = folder_size[1] * 0.6, folder_size[1] * 0.6
+            self.folder_button = pygame_gui.elements.UIButton(
+                relative_rect=pygame.Rect(*folder_button_pos, *folder_size),
                 text="",
                 manager=self,
-                object_id=pygame_gui.core.ObjectID("bot-settings", "settings_buttons"),
+                object_id=pygame_gui.core.ObjectID("bot-folder", "settings_buttons"),
             )
-            self.addButtonEvent("bot-settings", self.clickSettings)
-            if not self.settings_enable:
-                self.settings_button.disable()
-            settings_icon_path = find_abs("ui/settings.png", allowed_areas=asset_locations())
-            self.settings_icon = pygame_gui.elements.UIImage(
+            self.addButtonEvent("bot-folder", self.clickFolder)
+            if not self.folder_enable:
+                self.folder_button.disable()
+            folder_icon_path = find_abs("ui/folder_white.png", allowed_areas=asset_locations())
+            self.folder_icon = pygame_gui.elements.UIImage(
                 relative_rect=pygame.Rect(
-                    *self.iconPos(settings_button_pos, settings_size, settings_icon_size), *settings_icon_size
+                    *self.iconPos(folder_button_pos, folder_size, folder_icon_size), *folder_icon_size
                 ),
-                image_surface=pygame.image.load(settings_icon_path),
+                image_surface=pygame.image.load(folder_icon_path),
                 manager=self,
                 object_id=pygame_gui.core.ObjectID("settings-icon"),
             )
-            self._all_objs.append(self.settings_button)
-            self._all_objs.append(self.settings_icon)
+            self._all_objs.append(self.folder_button)
+            self._all_objs.append(self.folder_icon)
 
             edit_button_pos = (
                 self._size[0] * 0.9 - preview_size[0],
                 self._size[1] * 0.1 + preview_size[1] + 10,
             )
             self.edit_button = pygame_gui.elements.UIButton(
-                relative_rect=pygame.Rect(*edit_button_pos, *settings_size),
+                relative_rect=pygame.Rect(*edit_button_pos, *folder_size),
                 text="",
                 manager=self,
                 object_id=pygame_gui.core.ObjectID("bot-edit", "settings_buttons"),
@@ -189,7 +191,7 @@ class BotMenu(BaseMenu):
             edit_icon_path = find_abs("ui/edit.png", allowed_areas=asset_locations())
             self.edit_icon = pygame_gui.elements.UIImage(
                 relative_rect=pygame.Rect(
-                    *self.iconPos(edit_button_pos, settings_size, settings_icon_size), *settings_icon_size
+                    *self.iconPos(edit_button_pos, folder_size, folder_icon_size), *folder_icon_size
                 ),
                 image_surface=pygame.image.load(edit_icon_path),
                 manager=self,
@@ -279,6 +281,8 @@ class BotMenu(BaseMenu):
                 object_id=pygame_gui.core.ObjectID("select-done", "action_button"),
             )
             self.addButtonEvent("select-done", self.clickDone)
+            if self.key_index == 0:
+                self.done_button.disable()
             self._all_objs.append(self.done_button)
             super().generateObjects()
 
@@ -364,10 +368,12 @@ class BotMenu(BaseMenu):
             self.preview_images = [None] * len(self.bot_keys)
         self.bot_select_index = 0
         self.select_enable = False
-        self.settings_enable = False
+        self.folder_enable = False
         self.edit_enable = False
         self.remove_enable = False
         self.bot_index = -1
+        self.next = kwargs.get("next", None)
+        self.next_kwargs = kwargs.get("next_kwargs", {})
         super().initWithKwargs(**kwargs)
 
     def clickEdit(self):
@@ -384,22 +390,17 @@ class BotMenu(BaseMenu):
 
         ScreenObjectManager.instance.screens[ScreenObjectManager.SCREEN_BOT_EDIT].clearEvents()
 
-    def clickSettings(self):
-        # Shouldn't happen but lets be safe.
-        if self.bot_index == -1:
-            return
-        from ev3sim.visual.manager import ScreenObjectManager
-        from ev3sim.robot import visual_settings
+    def clickFolder(self):
+        # No more renaming.
+        import platform
+        import subprocess
 
-        ScreenObjectManager.instance.pushScreen(
-            ScreenObjectManager.SCREEN_SETTINGS,
-            file=self.available_bots[self.bot_index][1],
-            settings=visual_settings,
-            allows_filename_change=not self.available_bots[self.bot_index][2].startswith("package"),
-            extension="bot",
-        )
-
-        ScreenObjectManager.instance.screens[ScreenObjectManager.SCREEN_SETTINGS].clearEvents()
+        if platform.system() == "Windows":
+            subprocess.Popen(["explorer", "/select,", os.path.join(self.available_bots[self.bot_index][1], "code.py")])
+        elif platform.system() == "Darwin":
+            subprocess.Popen(["open", os.path.join(self.available_bots[self.bot_index][1], "code.py")])
+        else:
+            subprocess.Popen(["xdg-open", os.path.join(self.available_bots[self.bot_index][1], "code.py")])
 
     def clickSelect(self):
         # Shouldn't happen but lets be safe.
@@ -419,6 +420,8 @@ class BotMenu(BaseMenu):
         from ev3sim.visual.manager import ScreenObjectManager
 
         ScreenObjectManager.instance.popScreen()
+        if self.next is not None:
+            ScreenObjectManager.instance.pushScreen(self.next, **self.next_kwargs)
 
     def clickNew(self):
         from ev3sim.visual.manager import ScreenObjectManager
@@ -438,7 +441,9 @@ class BotMenu(BaseMenu):
         # Shouldn't happen but lets be safe.
         if self.bot_index == -1:
             return
-        os.remove(self.available_bots[self.bot_index][1])
+        import shutil
+
+        shutil.rmtree(self.available_bots[self.bot_index][1])
         self.setBotIndex(-1)
 
     def handleEvent(self, event):
@@ -449,12 +454,12 @@ class BotMenu(BaseMenu):
             elif event.key in [pygame.K_UP, pygame.K_s]:
                 self.incrementBotIndex(-1)
             elif event.key == pygame.K_RETURN:
-                self.clickSettings()
+                self.clickFolder()
 
     def setBotIndex(self, new_index):
         self.bot_index = new_index
         if len(self.bot_keys) == 0:
-            self.settings_enable = new_index != -1
+            self.folder_enable = new_index != -1
             self.edit_enable = new_index != -1
             self.remove_enable = new_index != -1 and not self.available_bots[new_index][2].startswith("package")
         else:
@@ -470,12 +475,10 @@ class BotMenu(BaseMenu):
         self.setBotIndex(new_index)
 
     def setBotAtIndex(self, index):
-        self.bot_values[index] = (
-            self.available_bots[self.bot_index][0] + "." + self.available_bots[self.bot_index][1].split(".")[-1]
-        )
-        with open(self.available_bots[self.bot_index][1], "r") as f:
+        self.bot_values[index] = self.available_bots[self.bot_index][0]
+        with open(os.path.join(self.available_bots[self.bot_index][1], "config.bot"), "r") as f:
             config = yaml.safe_load(f)
-        bot_preview = find_abs(config["preview_path"], allowed_areas=asset_locations())
+        bot_preview = os.path.join(self.available_bots[self.bot_index][1], config.get("preview_path", "preview.png"))
         self.preview_images[index] = pygame.image.load(bot_preview)
         self.regenerateObjects()
 
